==> angular-osm-0.0.2.tgz: package/README.md <==
Angular OSM
===========

[![NPM][npm-icon] ][npm-url]

[![Travis CI][travis-ci-image] ][travis-ci-url]
[![Codacy Badge][codacy-image] ][codacy-url]
[![semantic-release][semantic-image] ][semantic-url]

[![Quality][quality-badge] ][quality-url]
[![Coverage Status][coverage-image] ][coverage-url]
[![Circle CI] [circle-icon] ][circle-url]

[![dependencies][dependencies-image] ][dependencies-url]
[![devdependencies][devdependencies-image] ][devdependencies-url]

[npm-icon]: https://nodei.co/npm/angular-osm.png?downloads=true
[npm-url]: https://npmjs.org/package/angular-osm
[travis-ci-image]: https://travis-ci.org/toutpt/angular-osm.png?branch=master
[travis-ci-url]: https://travis-ci.org/toutpt/travis-ci

[coverage-image]: https://coveralls.io/repos/toutpt/angular-osm/badge.png
[coverage-url]: https://coveralls.io/r/toutpt/angular-osm
[dependencies-image]: https://david-dm.org/toutpt/angular-osm.png
[dependencies-url]: https://david-dm.org/toutpt/angular-osm
[devdependencies-image]: https://david-dm.org/toutpt/angular-osm/dev-status.png
[devdependencies-url]: https://david-dm.org/toutpt/angular-osm#info=devDependencies

[codacy-image]: https://api.codacy.com/project/badge/Grade/aa28c31e62114c2591e7a7e3161d48ca
[codacy-url]: https://www.codacy.com/public/toutpt/angular-osm.git
[semantic-image]: https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg
[semantic-url]: https://github.com/semantic-release/semantic-release

[quality-badge]: http://npm.packagequality.com/shield/angular-osm.svg
[quality-url]: http://packagequality.com/#?package=angular-osm

[circle-icon]: https://circleci.com/gh/toutpt/angular-osm.svg?style=svg
[circle-url]: https://circleci.com/gh/toutpt/angular-osm


Angular OSM is a set of angular services which provides API to use OSM APIs.

For more information please check the website : http://toutpt.github.io/angular-osm

==> angular-osm-0.0.3.tgz: package/README.md <==
Angular OSM
===========

[![NPM][npm-icon] ][npm-url]

[![Travis CI][travis-ci-image] ][travis-ci-url]
[![Codacy Badge][codacy-image] ][codacy-url]
[![semantic-release][semantic-image] ][semantic-url]

[![Quality][quality-badge] ][quality-url]
[![Coverage Status][coverage-image] ][coverage-url]
[![Circle CI] [circle-icon] ][circle-url]

[![dependencies][dependencies-image] ][dependencies-url]
[![devdependencies][devdependencies-image] ][devdependencies-url]

[npm-icon]: https://nodei.co/npm/angular-osm.png?downloads=true
[npm-url]: https://npmjs.org/package/angular-osm
[travis-ci-image]: https://travis-ci.org/toutpt/angular-osm.png?branch=master
[travis-ci-url]: https://travis-ci.org/toutpt/angular-osm

[coverage-image]: https://coveralls.io/repos/toutpt/angular-osm/badge.png
[coverage-url]: https://coveralls.io/r/toutpt/angular-osm
[dependencies-image]: https://david-dm.org/toutpt/angular-osm.png
[dependencies-url]: https://david-dm.org/toutpt/angular-osm
[devdependencies-image]: https://david-dm.org/toutpt/angular-osm/dev-status.png
[devdependencies-url]: https://david-dm.org/toutpt/angular-osm#info=devDependencies

[codacy-image]: https://api.codacy.com/project/badge/Grade/aa28c31e62114c2591e7a7e3161d48ca
[codacy-url]: https://www.codacy.com/public/toutpt/angular-osm.git
[semantic-image]: https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg
[semantic-url]: https://github.com/semantic-release/semantic-release

[quality-badge]: http://npm.packagequality.com/shield/angular-osm.svg
[quality-url]: http://packagequality.com/#?package=angular-osm

[circle-icon]: https://circleci.com/gh/toutpt/angular-osm.svg?style=svg
[circle-url]: https://circleci.com/gh/toutpt/angular-osm


Angular OSM is a set of angular services which provides API to use OSM APIs.

For more information please check the website : http://toutpt.github.io/angular-osm
